@@ -88,6 +88,26 @@ def get_many_list(db_client, query_list):
             #print("GET MANY RESULT: " + json.dumps(result_list))
             return result_list
 
+    except (Exception, pg8000.DatabaseError) as error:
+        print(error)
+        return False
+    finally:
+        db_client.commit()
+        db_client.close()
+
+
+def get_many_list_v2(db_client, query_list):
+
+    result_list = []
+    try:
+        for query in query_list:
+            #print("QUERY: " + query)
+            with db_client.cursor() as cursor:
+                cursor.execute(query)
+            result_list.append(cursor.fetchall())
+
+        return result_list
+
     except (Exception, pg8000.DatabaseError) as error:
         print(error)
         return False
