@@ -49,15 +49,19 @@ def in_required_list(required, payload):
         if item in payload and payload[item]:
             continue
         else:
-            return False
-    return True
+            return {
+                "error": item
+            }
+    return {}
 
 
 def in_allowed_list(allowed, payload):
     for item in payload:
         if item not in allowed:
-            return False
-    return True
+            return {
+                "error": item
+            }
+    return {}
 
 
 def if_empty(object):
